@@ -48,11 +48,29 @@ QTranslator translator, translator_qt, translator_qtbase;
 int main(int argc, char **argv) {
 
 	QApplication app(argc, argv);
+#if defined _WIN32 && (QT_VERSION >= QT_VERSION_CHECK(6, 5, 0))
+	app.setStyle("Fusion");
+#endif
 	app.setApplicationName("eqonomize");
 	app.setApplicationDisplayName("Eqonomize!");
 	app.setOrganizationName("Eqonomize");
 	app.setApplicationVersion(VERSION);
 
+	QSettings settings;
+	settings.beginGroup("GeneralOptions");
+
+	QString sfont = settings.value("font").toString();
+	QFont font;
+	if(!sfont.isEmpty()) {
+		font.fromString(sfont);
+		app.processEvents();
+		if(font.family() == app.font().family() && font.pointSize() == app.font().pointSize() && font.pixelSize() == app.font().pixelSize() && font.overline() == app.font().overline() && font.stretch() == app.font().stretch() && font.letterSpacing() == app.font().letterSpacing() && font.underline() == app.font().underline() && font.style() == app.font().style() && font.weight() == app.font().weight()) {
+			settings.remove("font");
+		} else {
+			app.setFont(font);
+		}
+	}
+
 	QString locale = setlocale(LC_MONETARY, NULL);
 	if(locale == QLocale::c().name()) {
 		setlocale(LC_MONETARY, QLocale::system().name().toLocal8Bit());
@@ -60,8 +78,6 @@ int main(int argc, char **argv) {
 		setlocale(LC_MONETARY, "");
 	}
 
-	QSettings settings;
-	settings.beginGroup("GeneralOptions");
 	QString slang = settings.value("language", QString()).toString();
 
 	EqonomizeTranslator eqtr;
@@ -196,11 +212,22 @@ int main(int argc, char **argv) {
 			win->createDefaultBudget();
 		}
 	}
-#ifdef RESOURCES_COMPILED
+
 	settings.beginGroup("GeneralOptions");
+#ifdef RESOURCES_COMPILED
 	if(!settings.value("lastVersionCheck").toDate().isValid() || settings.value("lastVersionCheck").toDate().addDays(10) <= QDate::currentDate()) win->checkAvailableVersion();
 #endif
 
+	//fixes font with gtk2 style
+	sfont = settings.value("font").toString();
+	if(!sfont.isEmpty()) {
+		QFont font;
+		font.fromString(sfont);
+		app.setFont(font);
+		win->updateAccountColumnWidths();
+	}
+	settings.endGroup();
+
 	args.clear();
 
 	return app.exec();
