@@ -21,9 +21,9 @@
 #ifndef SECURITY_H
 #define SECURITY_H
 
-#include <qstring.h>
-#include <qdatetime.h>
-#include <qmap.h>
+#include <QString>
+#include <QDateTime>
+#include <QMap>
 #include <QList>
 
 #include "transaction.h"
@@ -44,12 +44,12 @@ typedef enum {
 	SECURITY_TYPE_OTHER
 } SecurityType;
 
-static bool security_transaction_list_less_than(Transaction *t1, Transaction *t2) {
-	return t1->date() < t2->date();
-}
 template<class type> class SecurityTransactionList : public EqonomizeList<type> {
 	public:
 		SecurityTransactionList() : EqonomizeList<type>() {};
+		static bool security_transaction_list_less_than(Transaction *t1, Transaction *t2) {
+			return t1->date() < t2->date();
+		}
 		void sort() {
 			std::sort(QList<type>::begin(), QList<type>::end(), security_transaction_list_less_than);
 		}
@@ -57,13 +57,13 @@ template<class type> class SecurityTransactionList : public EqonomizeList<type>
 			QList<type>::insert(std::lower_bound(QList<type>::begin(), QList<type>::end(), value, security_transaction_list_less_than), value);
 		}
 };
-static bool scheduled_security_list_less_than(ScheduledTransaction *t1, ScheduledTransaction *t2) {
-	return t1->date() < t2->date();
-}
 
 template<class type> class ScheduledSecurityTransactionList : public EqonomizeList<type> {
 	public:
 		ScheduledSecurityTransactionList() : EqonomizeList<type>() {};
+		static bool scheduled_security_list_less_than(ScheduledTransaction *t1, ScheduledTransaction *t2) {
+			return t1->date() < t2->date();
+		}
 		void sort() {
 			std::sort(QList<type>::begin(), QList<type>::end(), scheduled_security_list_less_than);
 		}
@@ -71,12 +71,12 @@ template<class type> class ScheduledSecurityTransactionList : public EqonomizeLi
 			QList<type>::insert(std::lower_bound(QList<type>::begin(), QList<type>::end(), value, scheduled_security_list_less_than), value);
 		}
 };
-static bool traded_shares_list_less_than(SecurityTrade *t1, SecurityTrade *t2) {
-	return t1->date < t2->date;
-}
 template<class type> class TradedSharesList : public EqonomizeList<type> {
 	public:
 		TradedSharesList() : EqonomizeList<type>() {};
+		static bool traded_shares_list_less_than(SecurityTrade *t1, SecurityTrade *t2) {
+			return t1->date < t2->date;
+		}
 		void sort() {
 			std::sort(QList<type>::begin(), QList<type>::end(), traded_shares_list_less_than);
 		}
